The coverage criterion is defined by
$$coverage=\frac{1}{\bar{\gamma}} \left[ \frac{1}{n} \sum_{i=1}^{n}
\left( \gamma_{i} - \bar{\gamma} \right)^2 \right]^{1/2}$$
where \(\gamma_{i}\) is the minimal distance between the point \(x_{i}\)
and the other points of the design and \(\bar{\gamma}\) is
the mean of the \(\gamma_{i}\).
Note that for a regular mesh, cov=0. Then, a small value of cov means that the design is close to a regular grid.